Page 92 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 92

Home

    meeting for the first time, raised a specific question,
    which they discussed throughout the balance of the year
    in a very learned fashion. And the question is, Is there
    any means known more effective than war, assuming you
    wish to alter the life of an entire people? They conclude
    that no more effective means than war, to that end, is

    known to humanity.

    So then, in 1909, they raised the second question and
    discuss it. Namely, How do we involve the United States
    in a war? .. . Then finally they answer that question as
    follows, "We must control the State Department." And
    then that very naturally raises the question of how to do
    that. They answer it by saying we must take over and
    control the diplomatic machinery of this country, and
    finally they resolve to aim at that as an objective.

    Then time passes and we are eventually in a war,
    which would have been World War I. And at that time

    they record on their minutes a shocking report in which
    they dispatch to President Wilson a telegram cautioning
    him to see that the war does not end too quickly.

    And finally, of course, the war is over. At that time
    their interest shifts over to preventing what they call a
    reversion of life in the United States to what it was prior
    to 1914, when World War I broke out. And they, at that

    point, come to the conclusion that to prevent a reversion
    we must control education in the United States.°

    outlined whereby the grant-making power of the tax-free
    foundations were to be used to change the teaching of

    roe.

    history in the United States.
    Even then (1954) subversive forces were so strong
    that the Reece Committee was unable to complete its

    87

    Building Modern Babylon

    Mr. Dodd then went on to explain the method